@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Starts a user off based of an existing token.
 #
-# $Id: migrateuser.pm,v 1.13 2008/03/24 04:56:07 raeburn Exp $
+# $Id: migrateuser.pm,v 1.14 2008/09/15 19:08:44 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -94,14 +94,20 @@ sub handler {
 	if ($handle) {
 	    &Apache::lonnet::transfer_profile_to_env($r->dir_config('lonIDsDir'),
 						     $handle);
-	    if ($env{'request.course.id'}) {
-		$r->internal_redirect('/adm/navmaps');
+            if ($data{'origurl'} ne '') {
+                $r->internal_redirect($data{'origurl'});
+            } elsif ($env{'request.course.id'}) {
+                $r->internal_redirect('/adm/navmaps');
 	    } else {
 		$r->internal_redirect('/adm/roles');
 	    }
 	} else {
+            my $desturl = '/adm/roles';
+            if ($data{'origurl'} ne '') {
+                $desturl = $data{'origurl'};
+            }
 	    &Apache::lonauth::success($r,$data{'username'},$data{'domain'},
-				      $home,'/adm/roles',$extra_env);
+				      $home,$desturl,$extra_env);
 
 	}
 	return OK;
