@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.245.2.1 2008/09/19 22:31:54 raeburn Exp $
+# $Id: inputtags.pm,v 1.248.2.5 2008/12/18 15:56:23 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -358,8 +358,15 @@ sub start_textline {
 	     && $Apache::lonhomework::type ne 'exam') {
 	my $size = &Apache::lonxml::get_param('size',$parstack,$safeeval);
 	if ($size != 0) {$size=$size*2; $size.=' mm';} else {$size='40 mm';}
-	$result='\framebox['.$size.'][s]{\tiny\strut}';
-
+	if ($env{'form.pdfFormFields'} eq 'yes') {
+            my $fieldname = $env{'request.symb'}.
+                                 '&part_'. $Apache::inputtags::part.
+                                 '&textresponse'.
+                                 '&HWVAL_' . $Apache::inputtags::response['-1'];
+            $result="\n\\\\\n".'\textField{'.$fieldname.'}{'.$size.'}{12 bp}';
+        } else {
+            $result='\framebox['.$size.'][s]{\tiny\strut}';
+        }
     } elsif ($target eq 'tex' 
 	     && $Apache::lonhomework::type eq 'exam'
 	     && &needs_exam_box($tagstack)) {
@@ -420,13 +427,14 @@ sub end_hiddenline {
 # $part -> partid
 # $id -> responseid
 # $uploadefiletypes -> comma seperated list of extensions allowed or * for any
-# $which -> 'uploadedonly'  -> only newly uploaded files
+# $which -> 'uploadonly'  -> only newly uploaded files
 #           'portfolioonly' -> only allow files from portfolio
 #           'both' -> allow files from either location
 # $extratext -> additional text to go between the link and the input box
+# $maxfilesize -> maximum cumulative filesize for submitted files (in MB).
 # returns a table row <tr> 
 sub file_selector {
-    my ($part,$id,$uploadedfiletypes,$which,$extratext)=@_;
+    my ($part,$id,$uploadedfiletypes,$which,$extratext,$maxfilesize)=@_;
     if (!$uploadedfiletypes) { return ''; }
 
     my $jspart=$part;
@@ -435,9 +443,16 @@ sub file_selector {
     my $result;
     
     $result.='<tr><td>';
-    if ($uploadedfiletypes ne '*') {
-	$result.=
-	    &mt('Allowed filetypes: <b>[_1]</b>',$uploadedfiletypes).'<br />';
+    if (($uploadedfiletypes ne '*') || ($maxfilesize)) {
+        if ($uploadedfiletypes ne '*') {
+            $result.=
+                &mt('Allowed filetypes: [_1]','<b>'.$uploadedfiletypes.'</b>').'<br />';
+        }
+        if ($maxfilesize) {
+            $result.=&mt('Combined size of files not to exceed: [_1] MB[_2].',
+                         '<b>'.$maxfilesize.'</b>').'<br />';
+        }
+        $result .= '<br />';
     }
     if ($which eq 'uploadonly' || $which eq 'both') { 
 	$result.=&mt('Submit a file: (only one file can be uploaded)').
@@ -454,7 +469,6 @@ sub file_selector {
 	    '<input type="text" size="50" name="HWPORT'.$jspart.'_'.$id.'" value="" />'.
 	    '<br />';
 	$result .= &show_past_portfile_submission($part,$id);
-
     }
     $result.='</td></tr>'; 
     return $result;
@@ -516,9 +530,10 @@ sub valid_award {
 			       'UNIT_INVALID_STUDENT', 'UNIT_IRRECONCIBLE',
 			       'UNIT_FAIL', 'NO_UNIT',
 			       'UNIT_NOTNEEDED', 'WANTED_NUMERIC',
-			       'BAD_FORMULA', 'SIG_FAIL', 'INCORRECT', 
+			       'BAD_FORMULA', 'INTERNAL_ERROR', 'SIG_FAIL', 'INCORRECT', 
 			       'MISORDERED_RANK', 'INVALID_FILETYPE',
-			       'DRAFT', 'SUBMITTED', 'ASSIGNED_SCORE',
+                               'EXCESS_FILESIZE', 'DRAFT',
+			       'SUBMITTED', 'ASSIGNED_SCORE',
 			       'APPROX_ANS', 'EXACT_ANS','COMMA_FAIL') {
 	if ($award eq $possibleaward) { return 1; }
     }
@@ -530,10 +545,10 @@ sub valid_award {
 		  'TOO_LONG',
 		  'UNIT_INVALID_INSTRUCTOR', 'UNIT_INVALID_STUDENT',
 		  'UNIT_IRRECONCIBLE', 'UNIT_FAIL', 'NO_UNIT',
-		  'UNIT_NOTNEEDED', 'WANTED_NUMERIC', 'BAD_FORMULA',
+		  'UNIT_NOTNEEDED', 'WANTED_NUMERIC', 'BAD_FORMULA', 'INTERNAL_ERROR',
 		  'COMMA_FAIL', 'SIG_FAIL', 'INCORRECT', 'MISORDERED_RANK',
-		  'INVALID_FILETYPE', 'DRAFT', 'SUBMITTED', 'ASSIGNED_SCORE',
-		  'APPROX_ANS', 'EXACT_ANS');
+		  'INVALID_FILETYPE', 'EXCESS_FILESIZE', 'DRAFT', 'SUBMITTED',
+                  'ASSIGNED_SCORE', 'APPROX_ANS', 'EXACT_ANS');
     my $i=0;
     my %fwd_awards = map { ($_,$i++) } @awards;
     my $max=scalar(@awards);
@@ -578,6 +593,9 @@ sub finalizeawards {
 	    return ('NO_RESPONSE');
 	}
     }
+
+    if ($Apache::lonxml::internal_error) { $result='INTERNAL_ERROR'; }
+
     if (!$final_scantron && defined($result)) { return ($result); }
 
     # if in scantron mode, if the award for any response is 
@@ -754,6 +772,10 @@ sub decideoutput {
         }
 	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
+    } elsif ($award eq 'EXCESS_FILESIZE') {
+        $message = &mt('Submission won\'t be graded. The combined size of submitted files exceeded the amount allowed.');
+        $css_class=$possible_class{'not_charged_try'};
+        $button=1;
     } elsif ($award eq 'INVALID_FILETYPE') {
 	$message = &mt('Submission won\'t be graded. The type of file submitted is not allowed.');
 	$css_class=$possible_class{'not_charged_try'};
@@ -797,6 +819,10 @@ sub decideoutput {
         if ($target ne 'tex') {$message.=&Apache::loncommon::help_open_topic('Formula_Answers')};
 	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
+    } elsif ($award eq 'INTERNAL_ERROR') {
+        $message = &mt("An internal error occurred while processing your answer. Please try again later.");
+        $css_class=$possible_class{'not_charged_try'};
+        $button=1;
     } elsif ($award eq 'INCORRECT') {
 	$message = &mt("Incorrect").'.';
 	$css_class=$possible_class{'charged_try'};
@@ -828,14 +854,27 @@ sub decideoutput {
     my (undef,undef,$domain,$user)=&Apache::lonnet::whichuser();
     foreach my $resid(@Apache::inputtags::response){
         if ($Apache::lonhomework::history{"resource.$part.$resid.handback"}) {
-	    $message.='<br />';
+            if ($target eq 'tex') {
+                $message.= "\\\\\n";
+            } else {
+                $message.='<br />';
+            }
 	    my @files = split(/\s*,\s*/,
 			      $Apache::lonhomework::history{"resource.$part.$resid.handback"});
 	    my $file_msg;
 	    foreach my $file (@files) {
-		$file_msg.= '<br /><a href="/uploaded/'."$domain/$user".'/'.$file.'">'.$file.'</a>';
+                if ($target eq 'tex') {
+                    $file_msg.= "\\\\\n".$file;
+                } else {
+                    $file_msg.= '<br /><a href="/uploaded/'."$domain/$user".'/'.$file.'">'.$file.'</a>';
+                }
 	    }
 	    $message .= &mt('Returned file(s): [_1]',$file_msg);
+            if ($target eq 'tex') {
+                $message.= "\\\\\n";
+            } else {
+                $message.='<br />';
+            }
 	}
     }
 
@@ -1157,7 +1196,7 @@ sub get_grade_messages {
 		$trystr = '\vskip 0 mm ';
 	    }
 	} else {
-	    $trystr = "<td><nobr>".$tries_text." $tries";
+	    $trystr = '<td><span class="LC_nobreak">'.$tries_text." $tries";
 	    if ($Apache::lonhomework::parsing_a_task) {
 	    } elsif($env{'request.state'} ne 'construct') {
 		$trystr.="/$maxtries";
@@ -1166,7 +1205,7 @@ sub get_grade_messages {
 		    $trystr.="/".$Apache::inputtags::params{'maxtries'};
 		}
 	    }
-	    $trystr.="</nobr></td>";
+	    $trystr.="</span></td>";
 	}
     }
 
