@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # The LON-CAPA Homework handler
 #
-# $Id: lonhomework.pm,v 1.297 2008/09/05 17:43:32 raeburn Exp $
+# $Id: lonhomework.pm,v 1.298 2008/10/07 10:13:06 foxr Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -884,7 +884,7 @@ sub editxmlmode {
 	    &Apache::edit::js_change_detection(). 
 	    &Apache::loncommon::resize_textarea_js().
             &Apache::structuretags::setmode_javascript().
-            &Apache::lonhtmlcommon::dragmath_js();
+            &Apache::lonhtmlcommon::dragmath_js("EditMathPopup");
 	my $only_body =  ($env{'environment.remote'} eq 'off')? 0 : 1;
 	my $dragmath_button = 
             &Apache::lonhtmlcommon::dragmath_button("LC_editxmltext",1);
