@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Full matching style response
 #
-# $Id: matchresponse.pm,v 1.70 2008/08/08 16:37:13 bisitz Exp $
+# $Id: matchresponse.pm,v 1.73.2.1 2008/12/11 01:20:32 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -33,6 +33,7 @@ use Math::Random();
 use Apache::optionresponse();
 use Apache::lonlocal;
 use Apache::lonnet;
+use Apache::lonxml;
 
 BEGIN {
     &Apache::lonxml::register('Apache::matchresponse',('matchresponse'));
@@ -53,14 +54,16 @@ sub start_matchresponse {
 	$result=&Apache::response::meta_package_write('matchresponse');
     } elsif ($target eq 'edit' ) {
 	$result.=&Apache::edit::start_table($token).
-	    '<tr><td>'.&Apache::lonxml::description($token)."</td><td>Delete:".
-	    &Apache::edit::deletelist($target,$token)
-	    ."</td><td>&nbsp".&Apache::edit::end_row()
-	    .&Apache::edit::start_spanning_row();
+	    '<tr><td>'.&Apache::lonxml::description($token).'</td>'
+           .'<td><span class="LC_nobreak">'.&mt('Delete?').' '
+	   .&Apache::edit::deletelist($target,$token)
+           .'</span></td>'
+           .'<td>&nbsp;'.&Apache::edit::end_row()
+	   .&Apache::edit::start_spanning_row();
 	
 	$result.=
 	    &Apache::edit::text_arg('Max Number Of Shown Foils:','max',$token,'4').
-	    &Apache::edit::select_arg('Randomize Foil Order','randomize',
+	    &Apache::edit::select_arg('Randomize Foil Order:','randomize',
 				      ['yes','no'],$token).
 	    &Apache::edit::end_row().&Apache::edit::start_spanning_row()."\n";
     } elsif ($target eq 'modified') {
@@ -100,12 +103,12 @@ sub start_itemgroup {
     if ($target eq 'edit') {
 	$result=&Apache::edit::tag_start($target,$token);
 	$result.=&Apache::edit::select_arg('Randomize Order:','randomize',
-					   ['yes','no'],$token);
+					   ['yes','no'],$token).'&nbsp;'x 3;
 	$result.=&Apache::edit::select_arg('Items Display Location:',
 					   'location',
 					   ['top','bottom','left','right'],
-					   $token);
-	$result.=&Apache::edit::select_arg('Items Display Directection:',
+					   $token).'&nbsp;'x 3;
+	$result.=&Apache::edit::select_arg('Items Display Direction:',
 					   'direction',
 					   ['vertical','horizontal'],
 					   $token);
@@ -195,7 +198,8 @@ sub start_item {
 	$result=&Apache::edit::tag_start($target,$token,"Item");
 	$result.=&Apache::edit::text_arg('Name:','name',$token);
 	if ($randomize ne 'no') {
-	    $result.=&Apache::edit::select_arg('Location:','location',
+	    $result.='&nbsp;'x 3 .
+                     &Apache::edit::select_arg('Location:','location',
 					       ['random','top','bottom'],
 					       $token);
 	}
@@ -251,9 +255,11 @@ sub start_foilgroup {
     &Apache::response::pushrandomnumber();
     if ($target eq 'edit') {
 	$result.=&Apache::edit::start_table($token)
-	    ."<tr><td>Collection Of Foils</td><td>Delete:"
+	    .'<tr><td>'.&mt('Collection Of Foils').'</td>'
+            .'<td><span class="LC_nobreak">'.&mt('Delete?')
 	    .&Apache::edit::deletelist($target,$token)
-	    ."</td><td>&nbsp;".&Apache::edit::end_row()
+	    .'</span></td>'
+            .'<td>&nbsp;'.&Apache::edit::end_row()
             .&Apache::edit::start_spanning_row()."\n";
     }
     return $result;
@@ -507,15 +513,19 @@ sub displayfoils {
 		$optionlist="<option></option>\n";
 	    } else {
 		if ($Apache::lonhomework::type ne 'exam') {
-		    $optionlist='\framebox[5 mm][s]{\tiny\strut}';
-		}
+                    $optionlist='\framebox[10 mm][s]{\tiny\strut}';
+                }
 	    }
 	    my $option;
 	    foreach $option (@used_letters) {
 		if ($option eq $last_letter) {
-		    if ($target ne 'tex') {$optionlist.="<option selected=\"on\">$option</option>\n";}
+		    if ($target ne 'tex') {
+                        $optionlist.="<option selected=\"on\">$option</option>\n";
+                    }
 		} else {
-		    if ($target ne 'tex') {$optionlist.="<option>$option</option>\n";}
+		    if ($target ne 'tex') {
+                        $optionlist.="<option>$option</option>\n";
+                    }
 		}
 	    }
 	    if ($target ne 'tex' && $Apache::lonhomework::type ne 'exam') {
@@ -573,7 +583,7 @@ sub displayfoils {
 		    $question .= '\end{list} \vskip -8 mm \strut ';
 		    $internal_counter++;
 	        } else {
-		    $question.=' '.$optionlist.$text.'\strut\\\\\strut '."\n";
+                    $question.=' '.$optionlist.$text.'\strut\\\\\strut '."\n";
 		}
             } 
 	    $temp++;
