@@ -1,7 +1,7 @@
 # LearningOnline Network with CAPA
 # option list style responses
 #
-# $Id: optionresponse.pm,v 1.151 2008/08/08 16:37:13 bisitz Exp $
+# $Id: optionresponse.pm,v 1.151.2.1 2008/12/11 01:59:01 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -45,21 +45,23 @@ sub start_optionresponse {
   %Apache::hint::option=();
   undef(%Apache::response::foilnames);
   if ($target eq 'edit') {
-    $result.=&Apache::edit::start_table($token).
-	"<tr><td>Multiple Option Response Question ".
-	&Apache::loncommon::help_open_topic('Option_Response_Problems')."</td><td>Delete:".
-	&Apache::edit::deletelist($target,$token)
-	."</td><td>&nbsp;".
-        &Apache::edit::end_row().
-        &Apache::edit::start_spanning_row().
-        "\n";
+    $result.=&Apache::edit::start_table($token)
+       .'<tr><td><span class="LC_nobreak">'.&mt('Multiple Option Response Question').'</span> '
+       .&Apache::loncommon::help_open_topic('Option_Response_Problems')."</td>"
+       .'<td><span class="LC_nobreak">'.&mt('Delete?').' '
+       .&Apache::edit::deletelist($target,$token)
+       .'</span></td>'
+       ."<td>&nbsp;"
+       .&Apache::edit::end_row()
+       .&Apache::edit::start_spanning_row()
+       ."\n";
     $result.=&Apache::edit::text_arg('Max Number Of Shown Foils:','max',
 				     $token,'4').
-        &Apache::edit::select_arg('Randomize Foil Order','randomize',
+        &Apache::edit::select_arg('Randomize Foil Order:','randomize',
 				  ['yes','no'],$token).
         &Apache::edit::select_arg(&mt('Display of options when printed'),'TeXlayout',
-				  [['horizontal',&mt('Normal list')],
-				   ['vertical',&mt('Listed in a vertical column')]],$token).
+				  [['horizontal','Normal list'],
+				   ['vertical','Listed in a vertical column']],$token).
         &Apache::edit::end_row().&Apache::edit::start_spanning_row();
   } elsif ($target eq 'modified') {
     my $constructtag=&Apache::edit::get_new_args($token,$parstack,
