@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 # 
-# $Id: imsimport.pm,v 1.25 2008/08/26 01:35:15 www Exp $
+# $Id: imsimport.pm,v 1.26 2008/12/24 07:57:39 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -722,7 +722,7 @@ sub handler {
     my $fn;
     if ($env{'form.filename'}) {
         $fn=$env{'form.filename'};
-        $fn=~s/^http\:\/\/[^\/]+\///;
+        $fn=~s/^https?\:\/\/[^\/]+\///;
         $fn=~s/^\///;
         $fn=~s/(\~|priv\/)($LONCAPA::username_re)//;
         $fn=~s/\/+/\//g;
