@@ -3,7 +3,7 @@
 # institutional log-in ID (institutional authentication required - localauth
 #  or kerberos) or an e-mail address.
 #
-# $Id: createaccount.pm,v 1.25 2008/08/22 10:52:56 bisitz Exp $
+# $Id: createaccount.pm,v 1.26 2008/12/05 19:22:58 schafran Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -381,7 +381,7 @@ sub print_username_form {
     my %lt = &Apache::lonlocal::texthash(
                                          unam => 'username',
                                          udom => 'domain',
-                                         uemail => 'Email address in LON-CAPA',
+                                         uemail => 'E-mail address in LON-CAPA',
                                          proc => 'Proceed');
     my $output;
     if (ref($cancreate) eq 'ARRAY') {
