@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Bulletin Board Handler
 #
-# $Id: lonbulletin.pm,v 1.45 2008/01/19 15:28:52 raeburn Exp $
+# $Id: lonbulletin.pm,v 1.46 2008/03/03 11:25:59 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -181,7 +181,7 @@ sub handler {
           }
           $r->print(
 	  '<p>'.
-&Apache::loncommon::help_open_topic('Uploaded_Templates_TextBoxes','Help with filling in text boxes').'<br /><a href="'.$r->uri.'?'.$query_str.'"><font size="+1">'.&mt('Show Student View').'</font></a>'.
+&Apache::loncommon::help_open_topic('Uploaded_Templates_TextBoxes',&mt('Help with filling in text boxes')).'<br /><a href="'.$r->uri.'?'.$query_str.'"><font size="+1">'.&mt('Show Student View').'</font></a>'.
  &Apache::loncommon::help_open_topic('Uploaded_Templates_PublicView').'</p>');
       }  elsif ($privileged and $target ne 'tex') {
           my $query_str = 'forceedit=edit';
