@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Chat
 #
-# $Id: lonchat.pm,v 1.16 2008/01/19 21:40:41 raeburn Exp $
+# $Id: lonchat.pm,v 1.17 2009/01/12 04:11:25 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -62,7 +62,7 @@ sub handler {
 	&Apache::lonnet::chatsend(&Apache::lonfeedback::clear_out_html($env{'form.newchat'}),$env{'form.anonymous'},$group);
     }
 # --------------------------------------------------- Print login screen header
-    my $latexHelp = Apache::loncommon::helpLatexCheatsheet();
+    my $latexHelp = Apache::loncommon::helpLatexCheatsheet(undef,undef,1);
     my %loaditems = (onload => 'this.document.chatentry.newchat.focus();');
     my $start_page = 
 	&Apache::loncommon::start_page('Chat',undef,
