@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # handler for DC-only modifiable course settings
 #
-# $Id: lonmodifycourse.pm,v 1.39 2008/06/30 04:14:40 raeburn Exp $
+# $Id: lonmodifycourse.pm,v 1.40 2008/10/27 14:32:30 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -341,7 +341,7 @@ sub print_catsettings {
                 $excludeoff = ''; 
             }
             $r->print('<h4>'.&mt('Visibility in Course Catalog').'</h4>'.
-                      &mt("Unless excluded, a course is listed in this domain's publicly accessible course catalog, if at least of one the following applies").':<ul>'.
+                      &mt("Unless excluded, a course is listed in this domain's publicly accessible course catalog, if at least one of the following applies").':<ul>'.
                       '<li>'.&mt('Auto-cataloging is enabled and the course is assigned an institutional code').'</li>'.
                       '<li>'.&mt('The course has been categorized into at least one of the course categories defined for the domain.').'</li></ul>'.
                       &mt('Exclude from course catalog').'&nbsp;<label><input name="hidefromcat" type="radio" value="yes" '.$excludeon.' />'.&mt('Yes').'</label>&nbsp;&nbsp;&nbsp;<label><input name="hidefromcat" type="radio" value="" '.$excludeoff.' />'.&mt('No').'</label><br />'); 
