@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Routines for messaging
 #
-# $Id: lonmsg.pm,v 1.214.2.3 2008/12/23 19:27:33 raeburn Exp $
+# $Id: lonmsg.pm,v 1.214.2.5 2009/01/05 20:08:25 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -86,7 +86,7 @@ sub packagemsg {
     $baseurl =~ s|^https?\://[^/]+/|/|;
     $baseurl =&HTML::Entities::encode($baseurl,'<>&"');
     #remove machine specification
-    $attachmenturl =~ s|^https\://[^/]+/|/|;
+    $attachmenturl =~ s|^https?\://[^/]+/|/|;
     $attachmenturl =&HTML::Entities::encode($attachmenturl,'<>&"');
     my $course_context = &get_course_context();
     my $now=time;
@@ -283,21 +283,48 @@ sub unpackmsgid {
 
 sub sendemail {
     my ($to,$subject,$body,$to_uname,$to_udom,$user_lh)=@_;
-    my %senderemails=&Apache::loncommon::getemails();
     my $senderaddress='';
-    foreach my $type ('notification','permanentemail','critnotification') {
-	if ($senderemails{$type}) {
-	    $senderaddress=$senderemails{$type};
-	}
+    my $replytoaddress='';
+    if ($env{'form.can_reply'} eq 'N') {
+        my $lonhost = $Apache::lonnet::perlvar{'lonHostID'};
+        my $hostname = &Apache::lonnet::hostname($lonhost);
+        $replytoaddress = 'do-not-reply@'.$hostname;
+    } else {
+        my %senderemails;
+        my $have_sender;
+        if ($env{'form.reply_to_addr'}) {
+            my ($replytoname,$replytodom) = split(/:/,$env{'form.reply_to_addr'});
+            if (!($replytoname eq $env{'user.name'} && $replytodom eq $env{'user.domain'})) {
+                if (&Apache::lonnet::homeserver($replytoname,$replytodom) ne 'no_host') {
+                    %senderemails = 
+                        &Apache::loncommon::getemails($replytoname,$replytodom);
+                    $have_sender = 1;
+                }
+            }
+        }
+        if (!$have_sender) {
+            %senderemails=&Apache::loncommon::getemails();
+        }
+        foreach my $type ('permanentemail','critnotification','notification') {
+	    if ($senderemails{$type}) {
+                ($senderaddress) = split(/,/,$senderemails{$type});
+                last if ($senderaddress);
+	    }
+        }
     }
     $body=
     "*** ".&mt_user($user_lh,'This is an automatic message generated by the LON-CAPA system.')."\n".
     "*** ".($senderaddress?&mt_user($user_lh,'You can reply to this message'):&mt_user($user_lh,'Please do not reply to this address.')."\n*** ".
-	    &mt_user($user_lh,'A reply will not be received by the recipient!'))."\n\n".$body;
+    &mt_user($user_lh,'A reply will not be received by the recipient!'))."\n\n".$body;
     my $msg = new Mail::Send;
     $msg->to($to);
     $msg->subject('[LON-CAPA] '.$subject);
-    if ($senderaddress) { $msg->add('Reply-to',$senderaddress); $msg->add('From',$senderaddress); }
+    if ($replytoaddress) { 
+        $msg->add('Reply-to',$replytoaddress);
+    }
+    if ($senderaddress) {
+        $msg->add('From',$senderaddress); 
+    }
     if (my $fh = $msg->open()) {
 	print $fh $body;
 	$fh->close;
@@ -938,7 +965,7 @@ sub user_lang {
         @userlangs=(@userlangs,split(/\s*(\,|\;|\:)\s*/,
                     $env{'course.'.$fromcid.'.languages'}));
     } else {
-        my %langhash = &Apache::loncommon::getlangs($toudom,$touname);
+        my %langhash = &Apache::loncommon::getlangs($touname,$toudom);
         if ($langhash{'languages'} ne '') {
             @userlangs = split(/\s*(\,|\;|\:)\s*/,$langhash{'languages'});  
         } else {
