@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Sending messages
 #
-# $Id: lonnotify.pm,v 1.28 2008/09/16 03:30:30 raeburn Exp $
+# $Id: lonnotify.pm,v 1.32 2008/12/05 17:41:34 schafran Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -149,9 +149,9 @@ function next_page(caller) {
     $output .= '<input type="hidden" name="command" />';
     $output .= '<table class="LC_notify_front_page">'.
               '<tr><td><a href="javascript:next_page('."'new'".')">'.
-              'Send a new e-mail message to selected users from this domain</a></td></tr><tr>'.
+              &mt('Send a new e-mail to selected users from this domain').'</a></td></tr><tr>'.
               '<td><a href="javascript:next_page('."'view'".')">'.
-              'Display e-mail sent by Domain Coordinators in this domain'.
+              &mt('Display e-mail sent by Domain Coordinators in this domain').
               '</a></td></tr></table>';
     $output .= &end_page();
 
@@ -378,7 +378,7 @@ sub print_selection_form {
                'buil' => 'Building valid e-mail address from username, if missing from preferences:',
                'kerb' => 'Kerberos: enter default for each realm used in the domain, with comma separation of entries',
                'infs' => 'Internal, Filesystem and Local authentication: enter single default.',
-               'comp' => 'Compose Message'
+               'comp' => 'Compose E-mail'
            );
     &Apache::lonhtmlcommon::add_breadcrumb
           ({text=>"Select Audience"});
@@ -464,8 +464,8 @@ function setCourseCat(formname) {
 </ul>'."\n";
     my $submit_text = $lt{'comp'};
     my $cmd = 'compose';
-    $output .= &Apache::lonhtmlcommon::role_select_row(\@roles,'Roles');
-    $output .= &Apache::lonhtmlcommon::course_select_row('Courses',$formname,$totcodes,\@codetitles,\%idlist,\%idlist_titles);
+    $output .= &Apache::lonhtmlcommon::role_select_row(\@roles,&mt('Roles'));
+    $output .= &Apache::lonhtmlcommon::course_select_row(&mt('Courses'),$formname,$totcodes,\@codetitles,\%idlist,\%idlist_titles);
     $output .= &Apache::lonhtmlcommon::status_select_row(\%longtypes,&mt('Access status'));
     $output .= &Apache::lonhtmlcommon::email_default_row(\%authtypes,&mt('Username -> Email conversion'),$descrip);
     $output .= &Apache::lonhtmlcommon::submit_row(&mt('Submit'),$cmd,$submit_text);
@@ -480,7 +480,7 @@ sub print_composition_form {
     &Apache::lonhtmlcommon::add_breadcrumb
         ({href=>"javascript:goBack('pick_target')",
           text=>"Select Audience"},
-         {text=>"Compose Message"});
+         {text=>"Compose E-mail"});
     my $jscript = &Apache::loncommon::check_uncheck_jscript();
     $jscript .= qq|
 function goBack(target) {
@@ -642,7 +642,7 @@ function goBack(target) {
         $output .= &Apache::lonhtmlcommon::row_title(&mt('Sender e-mail address'));
         $output .= '<input type="text" name="sender" value="'.$sender.'" />';
         $output .= &Apache::lonhtmlcommon::row_closure();
-        $output .= &Apache::lonhtmlcommon::submit_row(&mt('Submit'),'process',&mt('Send Message'));
+        $output .= &Apache::lonhtmlcommon::submit_row(&mt('Submit'),'process',&mt('Send'));
         $output .= &Apache::lonhtmlcommon::end_pick_box();
     } else {
         $output .= $lt{'nore'}."\n".
@@ -674,7 +674,7 @@ ENDSCRIPT
           text=>"Select audience"});
     &Apache::lonhtmlcommon::add_breadcrumb
         ({href=>"javascript:goBack('compose')",
-          text=>"Compose Message"});
+          text=>"Compose E-mail"});
     &Apache::lonhtmlcommon::add_breadcrumb
         ({href=>"/adm/notify?command=process",
           text=>"Outcome"});
@@ -710,7 +710,7 @@ ENDSCRIPT
     } else {
         $output .= 'No mail sent - no recipients identified'; 
     }
-    $output .= '<br /><a href="/adm/notify">Send another message?</a>'."\n";
+    $output .= '<br /><a href="/adm/notify">'.&mt('Send another e-mail').'</a>'."\n";
     $output .= '<input type="hidden" name="command" />'."\n".
                '<input type="hidden" name="origin" value="'.$formname.'" />'."\n";
     $output .= &Apache::lonhtmlcommon::echo_form_input(['command','origin']);
@@ -769,9 +769,9 @@ sub get_user_info {
 sub form_elements {
    my ($longtypes,$authtypes) = @_;
    %{$longtypes} = (
-                   active => 'Currently has access',
-                   previous => 'Previously had access',
-                   future => 'Will have future access',
+                   active => &mt('Currently has access'),
+                   previous => &mt('Previously had access'),
+                   future => &mt('Will have future access'),
                    );
    %{$authtypes} = (
                    krb4 => 'Kerberos 4',
