@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Pick a student from the classlist
 #
-# $Id: lonpickstudent.pm,v 1.24 2007/09/02 01:30:34 raeburn Exp $
+# $Id: lonpickstudent.pm,v 1.25 2008/10/10 15:37:46 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -128,7 +128,7 @@ ENDSCRIPT
 						   &Apache::loncommon::course_type());
 		$r->print(&Apache::loncommon::start_data_table_row().
 			  '<td>'.
-			  '<input type="button" value="Select" onClick="gochoose('.
+			  '<input type="button" value="'.&mt('Select').'" onClick="gochoose('.
 			  "'".$puname."','".$pudom."')".'" /></td><td>'.$role.'</td><td>'.
 			  &Apache::loncommon::aboutmewrapper(&Apache::loncommon::plainname($puname,$pudom),$puname,$pudom).'</td>'.
 			  &Apache::loncommon::end_data_table_row());
@@ -219,7 +219,7 @@ ENDSCRIPT
 	    my ($uname,$udom) = split(':',$user);
 	    $r->print(&Apache::loncommon::start_data_table_row().
 		      '<td>'.
-		      '<input type="button" value="Select" onClick="gochoose('.
+		      '<input type="button" value="'.&mt('Select').'" onClick="gochoose('.
 		      "'".$uname."','".$udom."')".'" /></td>'.
 		      '<td><tt>'.$uname.'</tt></td>'.
 		      '<td><tt>'.$udom.'</tt></td><td>'.
