@@ -41,11 +41,6 @@ sub handler {
     if ($r->header_only) {
         return OK;
     }
-    my $start_page =
-        &Apache::loncommon::start_page('Reset password','',
-                                           {
-                                             'no_inline_link'   => 1,});
-    $r->print($start_page);
     my $contact_name = &mt('LON-CAPA helpdesk');
     my $contact_email =  $r->dir_config('lonSupportEMail');
     my $server = $r->dir_config('lonHostID');
@@ -58,7 +53,12 @@ sub handler {
     my $uname = &unescape($env{'form.uname'});
     my $udom = $env{'form.udom'};
     my $token = $env{'form.token'};
-    $r->print(&mt('<h3>'.&mt('Reset forgotten LON-CAPA password').'</h3>'));
+    my $start_page =
+        &Apache::loncommon::start_page('Reset password','',
+                                           {
+                                             'no_inline_link'   => 1,});
+    $r->print($start_page);
+    $r->print('<h3>'.&mt('Reset forgotten LON-CAPA password').'</h3>');
     my $output;
     if ($token) {
         $output = &reset_passwd($r,$token,$contact_name,$contact_email);
@@ -150,8 +150,7 @@ sub get_uname {
 sub send_token {
     my ($uname,$udom,$email,$server,$domdesc,$contact_name,
         $contact_email) = @_;
-    my $msg = &mt('Thank you for your request to reset the password for your
-        LON-CAPA account.').'<br /><br />';
+    my $msg = &mt('Thank you for your request to reset the password for your LON-CAPA account.').'<br /><br />';
 
     my $now = time;
     my $temppasswd = &create_passwd();
@@ -165,7 +164,7 @@ sub send_token {
     my $token = &Apache::lonnet::tmpput(\%info,$server,'resetpw');
     if ($token !~ /^error/ && $token ne 'no_such_host') {
         my $esc_token = &escape($token);
-        my $mailmsg = "A request was submitted on ".localtime(time)." for a reset of the ".
+        my $mailmsg = "A request was submitted on ".&Apache::lonlocal::locallocaltime(time)." for a reset of the ".
              "password for your LON-CAPA account.".
              "To complete this process please open a web browser and enter the following ".
              "URL in the address/location box: ".&Apache::lonnet::absolute_url()."/adm/resetpw?token=$esc_token";
@@ -242,14 +241,14 @@ sub reset_passwd {
         ($data{'domain'} ne '') && 
         ($data{'email'}  =~ /^[^\@]+\@[^\@]+\.[^\@\.]+$/) && 
         ($data{'temppasswd'} =~/^\w+$/)) {
-        my $reqtime = localtime($data{'time'});
+        my $reqtime = &Apache::lonlocal::locallocaltime($data{'time'});
         if ($now - $data{'time'} < 7200) {
             if ($env{'form.action'} eq 'verify_and_change_pass') {
                 my $change_failed = 
 		    &Apache::lonpreferences::verify_and_change_password($r,'reset_by_email',$token);
                 if (!$change_failed) {
                     my $delete = &Apache::lonnet::tmpdel($token);
-                    my $now = localtime(time);
+                    my $now = &Apache::lonlocal::locallocaltime(time);
                     my $domdesc = 
 			&Apache::lonnet::domain($data{'domain'},'description');
                     my $mailmsg = &mt('The password for your LON-CAPA account in the [_1] domain was changed [_2] from IP address: [_3].  If you did not perform this change or authorize it, please contact the [_4] ([_5]).',$domdesc,$now,$ENV{'REMOTE_ADDR'},$contact_name,$contact_email)."\n";
