@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construction Space Directory Lister
 #
-# $Id: lonpubdir.pm,v 1.110 2008/08/08 10:08:48 bisitz Exp $
+# $Id: lonpubdir.pm,v 1.110.2.1 2008/12/21 04:36:58 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -156,7 +156,7 @@ sub getEffectiveUrl {
 	#   Replace the ~username of the URL with /home/username/public_html
 	#   so that we don't have to worry about ~ expansion internally.
 	#
-	$fn=~s/^http\:\/\/[^\/]+\///;
+	$fn=~s/^https?\:\/\/[^\/]+\///;
         $fn=~s/^\///;
         $fn=~s{~($LONCAPA::username_re)}{/home/$1/public_html};
 	
