@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Page Handler
 #
-# $Id: lonpage.pm,v 1.87 2007/11/30 19:14:14 albertel Exp $
+# $Id: lonpage.pm,v 1.87.2.1 2008/12/21 04:29:47 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -339,7 +339,7 @@ sub handler {
                               }
                               $thisdir=~s/\/[^\/]*$//;
 			      foreach (@rlinks) {
-				  unless (($_=~/^http:\/\//i) ||
+				  unless (($_=~/^https?\:\/\//i) ||
 					  ($_=~/^\//) ||
 					  ($_=~/^javascript:/i) ||
 					  ($_=~/^mailto:/i) ||
