@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construct and maintain state and binary representation of course for user
 #
-# $Id: lonuserstate.pm,v 1.128 2008/03/12 02:45:50 raeburn Exp $
+# $Id: lonuserstate.pm,v 1.128.2.1 2008/12/21 04:46:53 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -247,7 +247,7 @@ sub parse_resource {
 	$turi=~/\.(\w+)$/;
 	my $embstyle=&Apache::loncommon::fileembstyle($1);
 	if ($token->[2]->{'external'} eq 'true') { # external
-	    $turi=~s/^http\:\/\//\/adm\/wrapper\/ext\//;
+	    $turi=~s/^https?\:\/\//\/adm\/wrapper\/ext\//;
 	} elsif ($turi=~/^\/*uploaded\//) { # uploaded
 	    if (($embstyle eq 'img') 
 		|| ($embstyle eq 'emb')
